; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;All we really gotta do is live and die
;but I'm in a hurry and don't know why

[Command]
name = "AI0"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI1"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI2"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI3"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI4"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI5"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI6"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI7"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI8"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI9"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI10"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI11"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI12"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI13"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI14"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI15"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI16"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI17"
command = a,B,c,x,y,z,s,B,D,F,U,a,b,c,x,y,z,s,s
time = 0
[Command]
name = "AI18"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI19"
command = b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b,b
time = 0
[Command]
name = "AI20"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI21"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI22"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI23"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI24"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI25"
command = F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F,F
time = 0
[Command]
name = "AI26"
command = D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D,D
time = 0
[Command]
name = "AI27"
command = B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B,B
time = 0
[Command]
name = "AI28"
command = U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U,U
time = 0
[Command]
name = "AI29"
command = a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a
time = 0
[Command]
name = "AI30"
command = c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c,c
time = 0
[Command]
name = "AI31"
command = x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x
time = 0
[Command]
name = "AI32"
command = y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y,y
time = 0
[Command]
name = "AI33"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI34"
command = s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s,s
time = 0
[Command]
name = "AI35"
command = z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI36"
command = z,z,z,z,z,z,a,a,a,z,z,z,z,z,z,z,z,z,z
time = 0
[Command]
name = "AI37"
command = z,a,a,a,a,a,a,a,a,a,a,a,a,a,a,a,z,z,z
time = 0
[Command]
name = "AI38"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,a,a,a,z,z,z
time = 0
[Command]
name = "AI39"
command = z,z,z,z,z,a,a,a,z,z,z,z,z,z,a,a,z,z,z
time = 0
[Command]
name = "AI40"
command = z,z,z,z,a,a,a,z,z,z,z,a,z,z,a,a,z,z,z
time = 

[Command]
name = "JuriAppears"
command = ~D, D, x+y
time = 20


[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "CannedHeat"
command = ~F, D, DF, x+y
time = 20

[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "nukleopatra"
command = ~D, DB, B, y

[Command]
name = "doyoureallywanttohurtme"
command = ~D, DB, B, x

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_xy"
command = ~D, B, x+y

[Command]
name = "QCF_x"
command = ~D, F, x

[Command]
name = "QCF_y"
command = ~D, F, y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "holds";Required (do not remove)
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
[State -1, JURI]
type = ChangeState
value = 3073
triggerall = power >= 3000
triggerall = statetype != A
triggerall = ctrl
trigger1 = command = "JuriAppears" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.1 > random && RoundState = 2 ; AI tries to counter
trigger2 = P2BodyDist X < 48 && EnemyNear,HitDefAttr = SCA,NA,SA

;---------------------------------------------------------------------------
[State -1, canned heat]
type = ChangeState
value = 3060
triggerall = StateType != A
triggerall = power >= 2000
triggerall = ctrl || hitdefattr = SCA,NA,SA,HA && movecontact
trigger1 = command = "CannedHeat" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger2 = StateNo = 1010 && MoveHit && AnimElem = 10, 1 && EnemyNear,Life > 140

;---------------------------------------------------------------------------
[State -1, mic toss]
type = ChangeState
value = 3050
triggerall = StateType != A
triggerall = power >= 1000
triggerall = ctrl || hitdefattr = SCA,NA,SA,HA && movecontact
trigger1 = command = "QCB_xy" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos after counter
trigger2 = StateNo = 1201 && Time = [8,12]

;---------------------------------------------------------------------------
;Love Bomb
;OJt[˂iQ[WxPj
[State -1, Love Bomb]
type = ChangeState
value = 3000
triggerall = power >= 1000
triggerall = ctrl || hitdefattr = SCA,NA,SA,HA && movecontact && StateNo != 3000
trigger1 = command = "QCF_xy" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger2 = StateNo = 1010 && MoveHit && AnimElem = 10, 1
trigger3 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger3 = StateNo = 610 && MoveHit
trigger4 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger4 = StateNo = 1010 && MoveHit && AnimElem = 10, 1 && EnemyNear,Life <= 140

;dance
;Jt[˂ij
[State -1, dance]
type = ChangeState
value = 1010
triggerall = StateType != A
triggerall = ctrl || (StateNo = [200,800)) && MoveContact
trigger1 = command = "nukleopatra" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.4 > random && RoundState = 2 ; AI combos
trigger2 = StateNo = 440 && MoveHit
trigger3 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger3 = StateNo = 210 && MoveHit && EnemyNear,StateType = A

;-------------------------------------------------------
;counter
[State -1, counter]
type = ChangeState
value = 1200
triggerall = StateType != A
triggerall = ctrl || (StateNo = [200,800)) && MoveContact
trigger1 = command = "doyoureallywanttohurtme" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.2 > random && RoundState = 2 ; AI tries to counter
trigger2 = P2BodyDist X < 48 && EnemyNear,HitDefAttr = SCA,NA,SA

;---------------------------------------------------------------------------
;feedback
;Jt[˂iQ[WxP^Rj
[State -1, feedback]
type = ChangeState
value = 1020
triggerall = StateType != A
triggerall = ctrl || (StateNo = [200,800)) && MoveContact
trigger1 = command = "QCF_y" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger2 = StateNo = 440 && MoveHit && Var(6) = 0
trigger3 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI erases
trigger3 = EnemyNear,NumProj > 0 || EnemyNear,HitDefAttr = SCA,AP

;---------------------------------------------------------------------------
;heart attack
;Jt[˂ij
[State -1, heart attack]
type = ChangeState
value = 1000
triggerall = StateType != A
triggerall = ctrl || (StateNo = [200,800)) && MoveContact
trigger1 = command = "QCF_x" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.1 > random && RoundState = 2 ; AI throws out
trigger2 = P2Dist X > 128 && EnemyNear,Pos Y > -40

;---------------------------------------------------------------------------

;===========================================================================
;---------------------------------------------------------------------------
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = statetype = S
triggerall = ctrl
trigger1 = command = "FF" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.4 > random && RoundState = 2 ; AI closes the gap
trigger2 = P2BodyDist X > 64 && P2MoveType != A

;---------------------------------------------------------------------------
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = statetype = S
triggerall = ctrl
trigger1 = command = "BB" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.5 > random && RoundState = 2 ; backs up
trigger2 = (P2StateNo = [5100,5120]) && P2BodyDist X < 16

;---------------------------------------------------------------------------
[State -1, Throw]
type = ChangeState
value = 800
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = p2bodydist X < 4
triggerall = (p2statetype = S) || (p2statetype = C)
triggerall = p2movetype != H
trigger1 = (command = "holdfwd" || command = "holdback") && command = "y" && !Var(15)

;===========================================================================
;---------------------------------------------------------------------------
[State -1, Stand L]
type = ChangeState
value = 200
triggerall = statetype = S
triggerall = ctrl || (stateno = 200 || stateno = 400) && MoveContact
trigger1 = command = "x" && command != "holddown" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI throws out
trigger2 = P2BodyDist X <= 24 && Abs(P2Dist Y) < 64 && Ctrl

;---------------------------------------------------------------------------
[State -1, Stand H]
type = ChangeState
value = 210
triggerall = statetype != A
triggerall = ctrl || (stateno = 200 || stateno = 400) && MoveContact
trigger1 = command = "y" && command != "holddown" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger2 = MoveContact

;---------------------------------------------------------------------------
[State -1, Dodge]
type = ChangeState
value = 230
triggerall = statetype != A
triggerall = ctrl
trigger1 = command = "a" && command != "holddown" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.5 > random && RoundState = 2 ; AI dodges from afar
trigger2 = P2Dist X > 128 && EnemyNear,MoveType = A
trigger3 = Var(15) && (Var(15)**3)*2*0.2 > random && RoundState = 2 ; AI dodges around
trigger3 = P2Dist X < 64 && EnemyNear,MoveType = A

;---------------------------------------------------------------------------
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = statetype != A
triggerall = ctrl
trigger1 = command = "start" && !Var(15)

;----------------------------------------------------------
[State -1, Crouch Slide]
type = ChangeState
value = 440
triggerall = statetype != A
triggerall = ctrl || (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && MoveContact
trigger1 = command = "y" && command = "holddown" && command = "holdfwd" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI combos
trigger2 = (StateNo = 210 || StateNo = 410) && MoveHit

;---------------------------------------------------------------------------
[State -1, Crouch L]
type = ChangeState
value = 400
triggerall = statetype != A
triggerall = ctrl || (stateno = 200 || stateno = 400) && MoveContact
trigger1 = command = "x" && command = "holddown" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.3 > random && RoundState = 2 ; AI tries to trip up
trigger2 = P2BodyDist X <= 24 && P2StateType = S

;---------------------------------------------------------------------------
[State -1, Crouch H]
type = ChangeState
value = 410
triggerall = statetype != A
triggerall = ctrl || (stateno = 200 || stateno = 400) && MoveContact
trigger1 = command = "y" && command = "holddown" && !Var(15)

;---------------------------------------------------------------------------
[State -1, Crouch Dodge]
type = ChangeState
value = 430
triggerall = statetype != A
triggerall = ctrl
trigger1 = command = "a" && command = "holddown" && !Var(15)

;---------------------------------------------------------------------------
[State -1, Air L]
type = ChangeState
value = 600
triggerall = statetype = A
triggerall = ctrl
trigger1 = command = "x" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI throws out
trigger2 = p2dist x < 64

;---------------------------------------------------------------------------
[State -1, Air H]
type = ChangeState
value = 610
triggerall = statetype = A
triggerall = ctrl || stateno = 600 && movecontact
trigger1 = command = "y" && !Var(15)
trigger2 = Var(15) && (Var(15)**3)*2*0.9 > random && RoundState = 2 ; AI throws out
trigger2 = movehit